@@ -134,7 +134,7 @@ class redis(object):
 		self.redis=redis.StrictRedis(host=host, port=port, db=db,decode_responses=True)
 	def __getattr__(self,attr):
 		return getattr(self.redis,attr)
-def process(target,is_thread=True,join=False,num=None,sleep=None,**args):
+def process(target,is_thread=True,join=False,num=1,sleep=None,**args):
 	if isinstance(target,str):#args:target,[sync]
 		import subprocess
 		proc=subprocess.Popen(target,stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE,shell=True);
@@ -143,9 +143,8 @@ def process(target,is_thread=True,join=False,num=None,sleep=None,**args):
 	if 'args' in args:
 		if isinstance(args['args'],list):
 			args_list=args['args']
-			if num is None:num=len(args_list)
+			if num==1:num=len(args_list)
 		else:args_list=[args['args']]*num
-	if num is None:num=1
 	if is_thread:
 		import threading
 		for x in range(num):
